--
-- MapSiloSave
--
-- M@D Author  Headshot XXL
-- M@D date 14.11.2009
--
-- > Copyright (C) Headshot XXL - www.planet-ls.de < --

print("Map: SaveSilo loaded");

MapSiloSave = {};

function MapSiloSave:loadMap(name)
	
	local dir = getUserProfileAppPath() .. "savegame"..gameMenuSystem.quickPlayMenu.selectedIndex;
    self.siloSaveXML = dir .. "/silo.xml";	
	
	self.siloBackup = {};
	for i=1, table.getn(g_currentMission.tipTriggers) do
		local entry = {};
		if g_currentMission.tipTriggers[i].movingId ~= nil then
			local x,y,z = getTranslation(g_currentMission.tipTriggers[i].movingId);				
			entry.yBackup = y;
			entry.name = getName(g_currentMission.tipTriggers[i].triggerId);				
		end;
		table.insert(self.siloBackup, entry);
	end;
	
	if g_missionLoaderDesc.stats.fuelUsage == 0 then
		os.remove(self.siloSaveXML);		
	else
		self:loadSiloFromFile()
	end;
	
	self.saved = 0;
	self.printSave = false;
	self.viewTime = 100;
	self.saveTime = 0;

end;

function MapSiloSave:deleteMap()
end;

function MapSiloSave:delete()
end;

function MapSiloSave:mouseEvent(posX, posY, isDown, isUp, button)
end;

function MapSiloSave:keyEvent(unicode, sym, modifier, isDown)
	
	if bitAND(modifier, Input.MOD_CTRL) > 0 and bitAND(modifier, Input.MOD_ALT) > 0 and InputBinding.isPressed(InputBinding.CAMERA_SWITCH) then
		self:saveSiloToXML();	
		self.saved = self.viewTime;		
	end;

end;

function MapSiloSave:update(dt)
	
	if self.saved <= self.viewTime+1 and self.saved > 0 then
		self.saved = self.saved - 1;
		self.printSave = true;
	elseif self.saved <= 0 then
		self.printSave = false;	
		self.saved = self.viewTime+2;
	end;	
	
	self.saveTime = self.saveTime + (dt/(1000*60));
	if self.saveTime > 5.00 then
		self.saveTime = 0;
		self:saveSiloToXML();
	end;
	
end;

function MapSiloSave:saveSiloToXML()	
	
	local existDir = io.open (self.siloSaveXML, "w");	
	if existDir == nil then
		createXMLFile("createsilo", self.siloSaveXML, "savesilo");
	end;

    -- save silo filllevel
    local siloFile = io.open (self.siloSaveXML, "w");
    if siloFile ~= nil then
        siloFile:write('<?xml version="1.0" encoding="iso-8859-1" standalone="no" ?>\n<siloSaves>\n');

        if g_currentMission ~= nil then
			for i=1, table.getn(g_currentMission.tipTriggers) do
				if g_currentMission.tipTriggers[i].movingId ~= nil then
					local x,y,z = getTranslation(g_currentMission.tipTriggers[i].movingId);
					siloFile:write('    <silo yHeight="'..y..'" name="'..getName(g_currentMission.tipTriggers[i].triggerId)..'" yBackup="'..self.siloBackup[i].yBackup..'" />\n');
				end;
			end;
        end;

        siloFile:write("</siloSaves>");

        siloFile:close();
    end;	
	
end;

function MapSiloSave:loadSiloFromFile()

	local existDir = io.open (self.siloSaveXML, "r");
	if existDir ~= nil then
		local xmlFile = loadXMLFile("TempConfig", self.siloSaveXML);
	
		local siloI = 0;
		for i=1, table.getn(g_currentMission.tipTriggers) do 
			if g_currentMission.tipTriggers[i].movingId ~= nil then
	
				local key = string.format("siloSaves.silo(%d)", siloI);
				local yHeight = getXMLFloat(xmlFile, key.."#yHeight");
				local name = getXMLString(xmlFile, key.."#name");
				local yBackup = getXMLFloat(xmlFile, key.."#yBackup");
				if yHeight == nil or name == nil or yBackup == nil then
					break;
				end;									
					local x,y,z = getTranslation(g_currentMission.tipTriggers[i].movingId);
					setTranslation(g_currentMission.tipTriggers[i].movingId, x, yHeight ,z);				
					self.siloBackup[i].yBackup = yBackup;
					
				siloI = siloI +1;
			end;
		end;
		
		delete(xmlFile);
	else
		print("Warning: ", self.siloSaveXML, " can not be found, SilagefillLevel not loaded.")
	end;

end;

function MapSiloSave:draw()
	
	if self.printSave then
		g_currentMission:addWarning("Silostaende wurden gespeichert", 0.018, 0.033);
	end;

end;

addModEventListener(MapSiloSave);

